@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: HuangJingCan
-@Date: 2020-04-22 14:32:40
-@LastEditTime: 2020-12-09 10:27:49
-@LastEditors: ChenXiaolei
-@Description: 用户信息扩展类
+:Author: HuangJingCan
+:Date: 2020-04-22 14:32:40
+:LastEditTime: 2020-12-09 10:27:49
+:LastEditors: ChenXiaolei
+:Description: 用户信息扩展类
 """
 
 from seven_studio.models.db_models.user.user_info_model import *
